package jp.veritrans.mpos.v2.sdk.sample.model;

import android.app.Activity;
import android.content.Context;
import android.content.SharedPreferences;

import java.util.HashMap;
import java.util.Map;

import jp.veritrans.mpos.v2.sdk.MposRequestParam;
import jp.veritrans.mpos.v2.sdk.sample.scene.Setting;

/**
 * 共通ヘッダーパラメータ用クラス
 */
public class CommonHeader {

	/** シングルトンインスタンス */
	private static CommonHeader instance;

	private CommonHeader() {
	}

	/**
	 * インスタンスの取得
	 *
	 * @return インスタンス
	 */
	public static CommonHeader getInstance() {
		if (instance == null) {
			instance = new CommonHeader();
		}
		return instance;
	}

	/**
	 * 保存されている共通ヘッダーパラメータ設定データから、引数用のデータを作成
	 *
	 * @param activity SharedPreferencesにて保存しているため
	 * @return 共通ヘッダーパラメータ
	 */
	public Map<String, String> getCommonHeaderParam(Activity activity) {
		Map<String, String> data = new HashMap<>();
		SharedPreferences preferences = activity.getSharedPreferences("SettingData", Context.MODE_PRIVATE);

		// 保存データからデータを作成
		// スイッチのデータがfalseなら、セットそのものを行わない
		data.put(MposRequestParam.USER_ID, preferences.getString(Setting.KEY_TEXT_USER_ID, ""));
		if (preferences.getBoolean(Setting.KEY_SWITCH_USER_PASSWORD, false)) {
			data.put(MposRequestParam.USER_PASSWORD, preferences.getString(Setting.KEY_TEXT_USER_PASSWORD, ""));
		}
		if (preferences.getBoolean(Setting.KEY_SWITCH_MERCHANT_PASSWORD, false)) {
			data.put(MposRequestParam.MERCHANT_PASSWORD, preferences.getString(Setting.KEY_TEXT_MERCHANT_PASSWORD, ""));
		}

		String tempStr = preferences.getString(Setting.KEY_TEXT_READER_TYPE, "");
		if (tempStr.equals("0")) {
			tempStr = "ipos";
		} else if (tempStr.equals("1")) {
			tempStr = "ctMP200";
		}
		data.put(MposRequestParam.READER_TYPE, tempStr);
		data.put(MposRequestParam.LOCALE, preferences.getString(Setting.KEY_TEXT_LOCALE, ""));
		if (preferences.getBoolean(Setting.KEY_SWITCH_CARD_THREE_WAY, false)) {
			data.put(MposRequestParam.CARD_THREE_WAY, preferences.getString(Setting.KEY_TEXT_CARD_THREE_WAY, ""));
		}
		if (preferences.getBoolean(Setting.KEY_SWITCH_CAMERA_FACING, false)) {
			data.put(MposRequestParam.CAMERA_FACING, preferences.getString(Setting.KEY_TEXT_CAMERA_FACING, ""));
		}

		return data;
	}
}
