package jp.veritrans.mpos.v2.sdk.sample.scene;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.widget.EditText;
import android.widget.Switch;

import java.util.HashMap;
import java.util.Map;

import jp.veritrans.mpos.v2.sdk.MposHandler;
import jp.veritrans.mpos.v2.sdk.MposPaymentListener;
import jp.veritrans.mpos.v2.sdk.MposRequestParam;
import jp.veritrans.mpos.v2.sdk.sample.R;
import jp.veritrans.mpos.v2.sdk.sample.model.ResponseLogMaker;
import jp.veritrans.mpos.v2.sdk.sample.util.TextUtil;

public class Payment extends SceneBase {

	private EditText editTextAmount;
	private EditText editTextDescription;
	private EditText editTextDisplayInputAmount;
	private EditText editTextDisplayComplete;
	private EditText editTextPaymentMethodCode;

	private Switch switchDescription;
	private Switch switchDisplayInputAmount;
	private Switch switchDisplayComplete;
	private Switch switchPaymentMethodCode;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		System.out.println("onCreate");
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_payment);
	}

	@Override
	public void setContentView(int layoutResID) {
		System.out.println("setContentView");
		super.setContentView(layoutResID);

		editTextAmount = findViewById(R.id.editTextAmount);
		editTextDescription = findViewById(R.id.editTextDescription);
		editTextDisplayInputAmount = findViewById(R.id.editTextDisplayInputAmount);
		editTextDisplayComplete = findViewById(R.id.editTextDisplayComplete);
		editTextPaymentMethodCode = findViewById(R.id.editTextPaymentMethodCode);

		switchDescription = findViewById(R.id.switchDescription);
		switchDisplayInputAmount = findViewById(R.id.switchDisplayInputAmount);
		switchDisplayComplete = findViewById(R.id.switchDisplayComplete);
		switchPaymentMethodCode = findViewById(R.id.switchPaymentMethodCode);

		// テキストボックスとクリアボタンの処理を紐づけ
		TextUtil.setClearEditTextButton(editTextDisplayInputAmount, R.id.clearButtonDisplayInputAmount);
		TextUtil.setClearEditTextButton(editTextDisplayComplete, R.id.clearButtonDisplayComplete);
		TextUtil.setClearEditTextButton(editTextPaymentMethodCode, R.id.clearButtonPaymentMethodCode);

	}

	public void onButtonStart(View v) {
		MposHandler sdkHandler = new MposHandler();

		// 共通ヘッダーパラメータ
		Map<String, String> headerParams = this.makeCommonHeaderParams();
		// リクエストパラメータ
		Map<String, String> requestParams = new HashMap<>();

		requestParams.put(MposRequestParam.AMOUNT, editTextAmount.getText().toString());

		if (switchDescription.isChecked()) {
			requestParams.put(MposRequestParam.ORDER_DESCRIPTION, editTextDescription.getText().toString());
		}
		if (switchDisplayInputAmount.isChecked()) {
			requestParams.put(MposRequestParam.INPUT_AMOUNT_VIEW, editTextDisplayInputAmount.getText().toString());
		}
		if (switchDisplayComplete.isChecked()) {
			requestParams.put(MposRequestParam.COMPLETE_VIEW, editTextDisplayComplete.getText().toString());
		}
		if (switchPaymentMethodCode.isChecked()) {
			requestParams.put(MposRequestParam.PAYMENT_METHOD_CODE, editTextPaymentMethodCode.getText().toString());
		}

		// 決済画面呼び出し
		final Context instance = this;
		sdkHandler.startPayment(this, new MposPaymentListener() {
			@Override
			public void onFinishPayment(final Map<String, String> response) {
				logSet(response);

				final CharSequence message = ResponseLogMaker.makeString(ResponseLogMaker.convertPaymentItems(response));
				System.out.println(message);

				Handler handler = new Handler(Looper.getMainLooper());
				handler.postDelayed(new Runnable() {
					@Override
					public void run() {
						AlertDialog dialog = new AlertDialog.Builder(instance).create();
						dialog.setMessage(message);
						dialog.setTitle("結果");
						dialog.setButton(DialogInterface.BUTTON_POSITIVE, "OK", new DialogInterface.OnClickListener() {
							@Override
							public void onClick(DialogInterface dialog, int which) {
							}
						});
						dialog.show();
					}
				}, 10);
			}
		}, headerParams, requestParams);
	}
}
