package jp.veritrans.mpos.v2.sdk.sample.scene;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.Switch;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import jp.veritrans.mpos.v2.sdk.MposCompleteListener;
import jp.veritrans.mpos.v2.sdk.MposHandler;
import jp.veritrans.mpos.v2.sdk.MposRequestParam;
import jp.veritrans.mpos.v2.sdk.MposResponseParam;
import jp.veritrans.mpos.v2.sdk.sample.R;
import jp.veritrans.mpos.v2.sdk.sample.model.ResponseLogMaker;

public class Search extends SceneBase {

	private EditText editTextTransactionCount;
	private EditText editTextOrderID;
	private EditText editTextOrderReferenceId;
	private EditText editTextRegisteredTimeFrom;
	private EditText editTextRegisteredTimeTo;

	private Switch switchOrderID;
	private Switch switchOrderReferenceId;
	private Switch switchRegisteredTimeFrom;
	private Switch switchRegisteredTimeTo;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_search);
	}

	@Override
	public void setContentView(int layoutResID) {
		super.setContentView(layoutResID);

		editTextTransactionCount = findViewById(R.id.editTextTransactionCount);
		editTextOrderID = findViewById(R.id.editTextOrderID);
		editTextOrderReferenceId = findViewById(R.id.editTextOrderReferenceId);
		editTextRegisteredTimeFrom = findViewById(R.id.editTextRegisteredTimeFrom);
		editTextRegisteredTimeTo = findViewById(R.id.editTextRegisteredTimeTo);

		switchOrderID = findViewById(R.id.switchOrderID);
		switchOrderReferenceId = findViewById(R.id.switchOrderReferenceId);
		switchRegisteredTimeFrom = findViewById(R.id.switchRegisteredTimeFrom);
		switchRegisteredTimeTo = findViewById(R.id.switchRegisteredTimeTo);
	}

	@SuppressWarnings("unchecked")
	public void onButtonStart(View v) {
		MposHandler sdkHandler = new MposHandler();

		// 共通ヘッダーパラメータ
		Map<String, String> headerParams = this.makeCommonHeaderParams();
		// リクエストパラメータ
		Map<String, String> requestParams = new HashMap<>();
		requestParams.put(MposRequestParam.TRANSACTION_COUNT, editTextTransactionCount.getText().toString());
		if (switchOrderID.isChecked()) {
			requestParams.put(MposRequestParam.ORDER_ID, editTextOrderID.getText().toString());
		}
		if (switchOrderReferenceId.isChecked()) {
			requestParams.put(MposRequestParam.ORDER_REFERENCE_ID, editTextOrderReferenceId.getText().toString());
		}
		if (switchRegisteredTimeFrom.isChecked()) {
			requestParams.put(MposRequestParam.REGISTERED_TIME_FROM, editTextRegisteredTimeFrom.getText().toString());
		}
		if (switchRegisteredTimeTo.isChecked()) {
			requestParams.put(MposRequestParam.REGISTERED_TIME_TO, editTextRegisteredTimeTo.getText().toString());
		}

		// 通信開始
		sdkHandler.requestSearchTransactionHistory(this, headerParams, requestParams, new MposCompleteListener() {
			@Override
			public void onComplete(final Map<String, Object> response) {
				logSet(response);

				CharSequence message = ResponseLogMaker.makeString(ResponseLogMaker.convertSearchItems(response));
				System.out.println(message);

				AlertDialog dialog = new AlertDialog.Builder(Search.this).create();
				dialog.setMessage(message);
				dialog.setTitle("結果");
				dialog.setButton(DialogInterface.BUTTON_POSITIVE, "OK", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						if (response.get(MposResponseParam.STATUS) == MposResponseParam.SUCCESS) {
							// リスト表示画面に遷移
							Intent intent = new Intent(Search.this, SearchList.class);
							ArrayList<HashMap<String, String>> historyList = (ArrayList<HashMap<String, String>>) response.get(MposResponseParam.HISTORY_LIST);
							intent.putExtra(MposResponseParam.HISTORY_LIST, historyList);
							startActivity(intent);
						}
					}
				});
				dialog.show();
			}
		});
	}
}
