package jp.veritrans.mpos.v2.sdk.sample.scene;

import android.content.Context;
import android.content.DialogInterface;
import android.content.SharedPreferences;
import android.content.res.Resources;
import android.os.Bundle;
import android.app.AlertDialog;
import android.view.View;
import android.widget.EditText;
import android.widget.Switch;

import java.io.IOException;
import java.util.Properties;

import jp.veritrans.mpos.v2.sdk.sample.BuildConfig;
import jp.veritrans.mpos.v2.sdk.sample.R;
import jp.veritrans.mpos.v2.sdk.sample.util.TextUtil;

public class Setting extends SceneBase {

	// 保存データキー
	public static final String KEY_TEXT_USER_ID = "textUserID";
	public static final String KEY_TEXT_USER_PASSWORD = "textUserPassword";
	public static final String KEY_TEXT_MERCHANT_PASSWORD = "textMerchantPassword";
	public static final String KEY_TEXT_READER_TYPE = "textReaderType";
	public static final String KEY_TEXT_APP_NAME = "textAppName";
	public static final String KEY_TEXT_APP_VERSION = "textAppVersion";
	public static final String KEY_TEXT_LOCALE = "textLocale";
	public static final String KEY_TEXT_CARD_THREE_WAY = "textCardThreeWay";
	public static final String KEY_TEXT_CAMERA_FACING = "textCameraFacing";
	public static final String KEY_SWITCH_USER_PASSWORD = "switchUserPassword";
	public static final String KEY_SWITCH_MERCHANT_PASSWORD = "switchMerchantPassword";
	public static final String KEY_SWITCH_CARD_THREE_WAY = "switchCardThreeWay";
	public static final String KEY_SWITCH_CAMERA_FACING = "switchCameraFacing";

	// 各種Viewインスタンス
	private EditText editTextUserID;
	private EditText editTextUserPassword;
	private EditText editTextMerchantPassword;
	private EditText editTextReaderType;
	private EditText editTextAppName;
	private EditText editTextAppVersion;
	private EditText editTextLocale;
	private EditText editTextCardThreeWay;
	private EditText editTextCameraFacing;
	private Switch switchUserPassword;
	private Switch switchMerchantPassword;
	private Switch switchMP200CardReadWaitingFor3;
	private Switch switchCameraFacing;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_setting);
	}

	@Override
	public void setContentView(int layoutResID) {
		super.setContentView(layoutResID);

		editTextUserID = findViewById(R.id.editTextUserID);
		editTextUserPassword = findViewById(R.id.editTextUserPassword);
		editTextMerchantPassword = findViewById(R.id.editTextMerchantPassword);
		editTextReaderType = findViewById(R.id.editTextReaderType);
		editTextAppName = findViewById(R.id.editTextAppName);
		editTextAppVersion = findViewById(R.id.editTextAppVersion);
		editTextLocale = findViewById(R.id.editTextLocale);
		editTextCardThreeWay = findViewById(R.id.editTextCardThreeWay);
		editTextCameraFacing = findViewById(R.id.editTextCameraFacing);

		switchUserPassword = findViewById(R.id.switchUserPassword);
		switchMerchantPassword = findViewById(R.id.switchMerchantPassword);
		switchMP200CardReadWaitingFor3 = findViewById(R.id.switchCardThreeWay);
		switchCameraFacing = findViewById(R.id.switchCameraFacing);

		// テキストボックスとクリアボタンの処理を紐づけ
		TextUtil.setClearEditTextButton(editTextReaderType, R.id.clearButtonReaderType);

		if (BuildConfig.DEBUG) {
			findViewById(R.id.buttonProperty).setVisibility(View.VISIBLE);
		} else {
			findViewById(R.id.buttonProperty).setVisibility(View.GONE);
		}

		SharedPreferences preferences = getSharedPreferences("SettingData", Context.MODE_PRIVATE);
		editTextUserID.setText(preferences.getString(KEY_TEXT_USER_ID, ""));
		editTextUserPassword.setText(preferences.getString(KEY_TEXT_USER_PASSWORD, ""));
		editTextMerchantPassword.setText(preferences.getString(KEY_TEXT_MERCHANT_PASSWORD, ""));
		editTextReaderType.setText(preferences.getString(KEY_TEXT_READER_TYPE, ""));
		editTextAppName.setText(preferences.getString(KEY_TEXT_APP_NAME, ""));
		editTextAppVersion.setText(preferences.getString(KEY_TEXT_APP_VERSION, ""));
		editTextLocale.setText(preferences.getString(KEY_TEXT_LOCALE, ""));
		editTextCardThreeWay.setText(preferences.getString(KEY_TEXT_CARD_THREE_WAY, ""));
		editTextCameraFacing.setText(preferences.getString(KEY_TEXT_CAMERA_FACING, ""));

		switchUserPassword.setChecked(preferences.getBoolean(KEY_SWITCH_USER_PASSWORD, false));
		switchMerchantPassword.setChecked(preferences.getBoolean(KEY_SWITCH_MERCHANT_PASSWORD, false));
		switchMP200CardReadWaitingFor3.setChecked(preferences.getBoolean(KEY_SWITCH_CARD_THREE_WAY, false));
		switchCameraFacing.setChecked(preferences.getBoolean(KEY_SWITCH_CAMERA_FACING, false));
	}

	/**
	 * 保存ボタンが押された時
	 *
	 * @param v ボタンView
	 */
	public void onButtonSave(View v) {
		AlertDialog dialog = new AlertDialog.Builder(this).create();

		dialog.setButton(DialogInterface.BUTTON_POSITIVE, "OK", new DialogInterface.OnClickListener() {
			@Override
			public void onClick(DialogInterface dialog, int which) {
			}
		});

		if (saveData()) {
			dialog.setMessage("保存しました");
		} else {
			dialog.setMessage("保存に失敗しました");
		}

		dialog.show();
	}

	/**
	 * データを保存する
	 */
	private boolean saveData() {
		String userID = editTextUserID.getText().toString();
		String userPassword = editTextUserPassword.getText().toString();
		String merchantPassword = editTextMerchantPassword.getText().toString();
		String readerType = editTextReaderType.getText().toString();
		String appName = editTextAppName.getText().toString();
		String appVersion = editTextAppVersion.getText().toString();
		String locale = editTextLocale.getText().toString();
		String cardThreeWay = editTextCardThreeWay.getText().toString();
		String cameraFacing = editTextCameraFacing.getText().toString();

		boolean switchUserPasswordValue = switchUserPassword.isChecked();
		boolean switchMerchantPasswordValue = switchMerchantPassword.isChecked();
		boolean switchMP200CardReadWaitingFor3Value = switchMP200CardReadWaitingFor3.isChecked();
		boolean switchCameraFacingValue = switchCameraFacing.isChecked();

		// データの保存
		SharedPreferences preferences = getSharedPreferences("SettingData", Context.MODE_PRIVATE);
		SharedPreferences.Editor editor = preferences.edit();
		editor.putString(KEY_TEXT_USER_ID, userID);
		editor.putString(KEY_TEXT_USER_PASSWORD, userPassword);
		editor.putString(KEY_TEXT_MERCHANT_PASSWORD, merchantPassword);
		editor.putString(KEY_TEXT_READER_TYPE, readerType);
		editor.putString(KEY_TEXT_APP_NAME, appName);
		editor.putString(KEY_TEXT_APP_VERSION, appVersion);
		editor.putString(KEY_TEXT_LOCALE, locale);
		editor.putString(KEY_TEXT_CARD_THREE_WAY, cardThreeWay);
		editor.putString(KEY_TEXT_CAMERA_FACING, cameraFacing);
		editor.putBoolean(KEY_SWITCH_USER_PASSWORD, switchUserPasswordValue);
		editor.putBoolean(KEY_SWITCH_MERCHANT_PASSWORD, switchMerchantPasswordValue);
		editor.putBoolean(KEY_SWITCH_CARD_THREE_WAY, switchMP200CardReadWaitingFor3Value);
		editor.putBoolean(KEY_SWITCH_CAMERA_FACING, switchCameraFacingValue);

		return editor.commit();
	}

	/**
	 * プロパティ設定反映ボタンが押された時
	 *
	 * @param v ボタンView
	 */
	public void onButtonProperty(View v) {
		// セーブデータの反映

		Resources r = this.getResources();
		Properties properties = new Properties();
		try {
			properties.loadFromXML(r.getAssets().open("properties.xml"));
		} catch (IOException e) {
			e.printStackTrace();
		}

		editTextUserID.setText(properties.getProperty("debug.userID", ""));
		editTextUserPassword.setText(properties.getProperty("debug.userPassword", ""));
		editTextMerchantPassword.setText(properties.getProperty("debug.merchantPassword", ""));
		editTextReaderType.setText(properties.getProperty("debug.readerType", ""));
		editTextAppName.setText(properties.getProperty("debug.appName", ""));
		editTextAppVersion.setText(properties.getProperty("debug.appVersion", ""));
		editTextLocale.setText(properties.getProperty("debug.locale", ""));
		editTextCardThreeWay.setText(properties.getProperty("debug.cardThreeWay", ""));
		editTextCameraFacing.setText(properties.getProperty("debug.cameraFacing", ""));
	}
}
