package jp.veritrans.mpos.v2.sdk.sample.util;

import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;

/**
 * テキストユーティリティ。
 */
public class TextUtil {

	/**
	 * EditTextをクリアするボタン設定
	 *
	 * @param editText クリアボタンでクリアするEditText
	 * @param clearButtonId クリアボタンリソースID
	 */
	public static void setClearEditTextButton(final EditText editText, int clearButtonId) {
		final Button clearButton = ((ViewGroup) editText.getParent()).findViewById(clearButtonId);

		// 現状の入力内容によりクリアボタンの表示/非表示
		String str = editText.getText().toString();
		clearButton.setVisibility(!TextUtils.isEmpty(str) ? View.VISIBLE : View.GONE);

		// 入力中の内容によりクリアボタンの表示/非表示
		editText.addTextChangedListener(new TextWatcher() {
			@Override
			public void onTextChanged(CharSequence s, int start, int before, int count) {
			}

			@Override
			public void beforeTextChanged(CharSequence s, int start, int count, int after) {
			}

			@Override
			public void afterTextChanged(Editable s) {
				clearButton.setVisibility(!TextUtils.isEmpty(s) ? View.VISIBLE : View.GONE);
			}
		});

		// クリアボタン処理
		clearButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				editText.setText("");
				clearButton.setVisibility(View.GONE);
			}
		});
	}
}
